/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.junit;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.ow2.petals.admin.api.ArtifactAdministration;
import org.ow2.petals.admin.api.artifact.Artifact;
import org.ow2.petals.admin.api.artifact.ServiceAssembly;
import org.ow2.petals.admin.api.artifact.lifecycle.ArtifactLifecycle;
import org.ow2.petals.admin.api.artifact.lifecycle.ArtifactLifecycleFactory;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;
import org.ow2.petals.admin.api.exception.ArtifactNotFoundException;
import org.ow2.petals.admin.api.exception.ArtifactTypeIsNeededException;
import org.ow2.petals.admin.topology.Container;
import org.ow2.petals.admin.topology.Domain;

/**
 * 
 * @author Mathieu CARROLLE - EBM WebSourcing
 * @author Christophe DENEUX - Linagora
 * 
 */
public class ArtifactAdministrationMock extends ArtifactAdministration {

    private final Domain domain;

    public ArtifactAdministrationMock(final Domain domain,
            final ArtifactLifecycleFactory artifactLifecycle) {
        super(artifactLifecycle);
        this.domain = domain;
    }

    private List<Artifact> allArtifacts() {
        final List<Artifact> artifacts = new ArrayList<Artifact>();
        for (final Container container : this.domain.getContainers()) {
            artifacts.addAll(container.getSharedLibraries());
            artifacts.addAll(container.getComponents());
            for (final ServiceAssembly serviceAssembly : container.getServiceAssemblies()) {
                artifacts.add(serviceAssembly);
                artifacts.addAll(serviceAssembly.getServiceUnits());
            }
        }
        return artifacts;
    }

    @Override
    public void stopAndUndeployAllArtifacts() throws ArtifactAdministrationException {

        for (final Artifact a : this.allArtifacts()) {
            final ArtifactLifecycle aLifecycle = this.artifactLifecycleFactory.createLifecycle(a);
            aLifecycle.stop();
            aLifecycle.undeploy();
        }
    }

    @Override
    public List<Artifact> listArtifacts() throws ArtifactAdministrationException {
        return Collections.unmodifiableList(this.allArtifacts());
    }

    @Override
    public Artifact getArtifact(final String type, final String name, final String version)
            throws ArtifactAdministrationException {
        assert name != null;

        final List<Artifact> artifacts = this.allArtifacts();
        final List<Artifact> artifactsMatchingName = new ArrayList<Artifact>();
        for (final Artifact artifact : artifacts) {
            if ((type == null || (type != null && artifact.getType().equals(type))) && artifact.getName().equals(name)
                    && (version == null || (version != null && artifact.getVersion().equals(version)))) {
                artifactsMatchingName.add(artifact);
            }
        }
        if (artifactsMatchingName.size() == 0) {
            throw new ArtifactNotFoundException(type, name, version);
        } else if (artifactsMatchingName.size() > 1) {
            throw new ArtifactTypeIsNeededException(name);
        } else {
            return artifactsMatchingName.get(0);
        }
    }

}
