/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.junit;

import java.net.URL;

import org.ow2.petals.admin.api.artifact.ArtifactState.State;
import org.ow2.petals.admin.api.artifact.Component;
import org.ow2.petals.admin.api.artifact.lifecycle.ComponentLifecycle;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;
import org.ow2.petals.admin.api.exception.ArtifactNotFoundException;
import org.ow2.petals.admin.api.exception.ArtifactUnsupportedOperationException;
import org.ow2.petals.admin.topology.Container;

/**
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 */
public class ComponentLifecycleMock implements ComponentLifecycle {

    /**
     * Container on which the Petals Administration API is connected
     */
    private final Container container;

    private final Component component;

    public ComponentLifecycleMock(final Component c, final Container container) {
        this.component = c;
        this.container = container;
    }

    @Override
    public void deploy(final URL artifactUrl) throws ArtifactAdministrationException {
        this.container.addComponent(this.getComponent());
    }

    @Override
    public void start() throws ArtifactAdministrationException {
        final int found = this.container.getComponents().indexOf(this.getComponent());
        if (found < 0) {
            throw new ArtifactNotFoundException(this.component.getType(), this.component.getName(),
                    this.component.getVersion());
        }
        this.container.getComponents().get(found).setState(State.STARTED);

    }

    @Override
    public void stop() throws ArtifactAdministrationException {
        final int found = this.container.getComponents().indexOf(this.getComponent());
        if (found < 0) {
            throw new ArtifactNotFoundException(this.component.getType(), this.component.getName(),
                    this.component.getVersion());
        }
        this.container.getComponents().get(found).setState(State.STOPPED);
    }

    @Override
    public void undeploy() throws ArtifactAdministrationException {
        final int found = this.container.getComponents().indexOf(this.getComponent());
        if (found < 0) {
            throw new ArtifactNotFoundException(this.component.getType(), this.component.getName(),
                    this.component.getVersion());
        }
        this.container.removeComponent(this.getComponent());
    }

    @Override
    public void updateState() throws ArtifactAdministrationException {
        final int found = this.container.getComponents().indexOf(this.getComponent());
        if (found < 0) {
            throw new ArtifactNotFoundException(this.component.getType(), this.component.getName(),
                    this.component.getVersion());
        }
        this.getComponent().setState(this.container.getComponents().get(found).getState());
    }

    @Override
    public Component getComponent() {
        return this.component;
    }

    @Override
    public void reloadConfiguration() throws ArtifactNotFoundException, ArtifactUnsupportedOperationException,
            ArtifactAdministrationException {
        final int found = this.container.getComponents().indexOf(this.getComponent());
        if (found < 0) {
            throw new ArtifactNotFoundException(this.component.getType(), this.component.getName(),
                    this.component.getVersion());
        }
    }
}