/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.junit;

import java.net.URL;

import org.ow2.petals.admin.api.artifact.ArtifactState.State;
import org.ow2.petals.admin.api.artifact.ServiceAssembly;
import org.ow2.petals.admin.api.artifact.lifecycle.ServiceAssemblyLifecycle;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;
import org.ow2.petals.admin.topology.Container;

/**
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 */
public class ServiceAssemblyLifecycleMock implements ServiceAssemblyLifecycle {

    /**
     * Container on which the Petals Administration API is connected
     */
    private final Container container;

    private final ServiceAssembly sa;

    public ServiceAssemblyLifecycleMock(final ServiceAssembly sa, final Container container) {
        this.sa = sa;
        this.container = container;
    }

    @Override
    public void deploy(final URL artifactUrl) throws ArtifactAdministrationException {
        this.container.addServiceAssembly(this.getServiceAssembly());
    }

    @Override
    public void start() throws ArtifactAdministrationException {
        final int found = this.container.getServiceAssemblies().indexOf(this.getServiceAssembly());
        if (found < 0) {
            throw new ArtifactAdministrationException("Artifact not found in registry. Can not update state");
        }
        this.container.getServiceAssemblies().get(found).setState(State.STARTED);

    }

    @Override
    public void stop() throws ArtifactAdministrationException {
        final int found = this.container.getServiceAssemblies().indexOf(this.getServiceAssembly());
        if (found < 0) {
            throw new ArtifactAdministrationException("Artifact not found in registry. Can not update state");
        }
        this.container.getServiceAssemblies().get(found).setState(State.STOPPED);
    }

    @Override
    public void undeploy() throws ArtifactAdministrationException {
        this.container.removeServiceAssembly(this.getServiceAssembly());
    }

    @Override
    public void updateState() throws ArtifactAdministrationException {
        final int found = this.container.getServiceAssemblies().indexOf(this.getServiceAssembly());
        if (found < 0) {
            throw new ArtifactAdministrationException("Artifact not found in registry. Can not update state");
        }
        getServiceAssembly().setState(this.container.getServiceAssemblies().get(found).getState());
    }

    @Override
    public ServiceAssembly getServiceAssembly() {
        return this.sa;
    }
}
