/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.junit;

import java.net.URL;

import org.ow2.petals.admin.api.artifact.SharedLibrary;
import org.ow2.petals.admin.api.artifact.lifecycle.SharedLibraryLifecycle;
import org.ow2.petals.admin.api.exception.ArtifactAdministrationException;
import org.ow2.petals.admin.topology.Container;

/**
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 */
public class SharedLibraryLifecycleMock implements SharedLibraryLifecycle {

    /**
     * Container on which the Petals Administration API is connected
     */
    private final Container container;

    private final SharedLibrary sl;

    public SharedLibraryLifecycleMock(final SharedLibrary sl, final Container container) {
        this.sl = sl;
        this.container = container;
    }

    @Override
    public void deploy(final URL artifactUrl) throws ArtifactAdministrationException {
        this.container.addSharedLibrary(this.getSharedLibrary());
    }

    @Override
    public void start() throws ArtifactAdministrationException {
        // Starting a shared library has no sens
    }

    @Override
    public void stop() throws ArtifactAdministrationException {
        // Stopping a shared library has no sens
    }

    @Override
    public void undeploy() throws ArtifactAdministrationException {
        this.container.removeSharedLibrary(this.getSharedLibrary());
    }

    @Override
    public void updateState() throws ArtifactAdministrationException {
        // Changing state of a shared library has no sens
    }

    @Override
    public SharedLibrary getSharedLibrary() {
        return this.sl;
    }
}
