/**
 * Copyright (c) 2014-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.junit.utils;

import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;

import org.ow2.petals.admin.api.artifact.Component;
import org.ow2.petals.admin.api.artifact.Component.ComponentType;
import org.ow2.petals.admin.api.artifact.ServiceAssembly;
import org.ow2.petals.admin.api.artifact.SharedLibrary;
import org.ow2.petals.admin.topology.Container;
import org.ow2.petals.admin.topology.Container.PortType;
import org.ow2.petals.admin.topology.Container.State;
import org.ow2.petals.admin.topology.Domain;

public class DomainUtils {

    final public static String DOMAIN_NAME = "my-domain";

    final public static String CONTAINER_00_NAME = "my-container-0-0";

    final public static String CONTAINER_00_HOST = "localhost";

    final public static int CONTAINER_00_JMX_PORT = 7700;

    final public static String CONTAINER_00_USERNAME = "petals";

    final public static String CONTAINER_00_PWD = "petals";

    final public static String CONTAINER_01_NAME = "my-container-0-1";

    final public static String CONTAINER_01_HOST = "localhost";

    final public static int CONTAINER_01_JMX_PORT = 7701;

    final public static String CONTAINER_01_USERNAME = "petals";

    final public static String CONTAINER_01_PWD = "petals";

    final public static String SL_00_0_NAME = "shared-library-00-0";

    final public static String SL_00_0_VERSION = "1.0";

    final public static String BINDING_00_0 = "binding-component-00-0";

    final public static String ENGINE_01_0 = "service-engine-01-0";

    final public static String ENGINE_01_1 = "service-engine-01-1";

    final public static String SA_01_0 = "service-assembly-01-0";

    /**
     * Create a sample domain with the following definition:
     * <ul>
     * <li>container #0: 1 SL, 1 BC,</li>
     * <li>container #1: 2 SE, 1 SA.</li>
     * </ul>
     */
    public final static Domain createDomainSample() {
        final Domain domain = new Domain(DOMAIN_NAME);
        final Map<Container.PortType, Integer> container00_ports = new HashMap<Container.PortType, Integer>();
        container00_ports.put(PortType.JMX, Integer.valueOf(CONTAINER_00_JMX_PORT));
        final Container container00 = new Container(CONTAINER_00_NAME, CONTAINER_00_HOST, container00_ports,
                CONTAINER_00_USERNAME, CONTAINER_00_PWD, State.REACHABLE);
        // TODO: The property 'petals.container.name' must be defined in an API usable by Petals CLI
        container00.addProperty("petals.container.name", CONTAINER_00_NAME);
        container00.addSharedLibrary(new SharedLibrary(SL_00_0_NAME, SL_00_0_VERSION));
        container00.addComponent(new Component(BINDING_00_0, ComponentType.BC));

        final Map<Container.PortType, Integer> container01_ports = new HashMap<Container.PortType, Integer>();
        container01_ports.put(PortType.JMX, Integer.valueOf(CONTAINER_00_JMX_PORT));
        final Container container01 = new Container(CONTAINER_01_NAME, CONTAINER_01_HOST, container01_ports,
                CONTAINER_01_USERNAME, CONTAINER_01_PWD, State.UNREACHABLE);
        // TODO: The property 'petals.container.name' must be defined in an API usable by Petals CLI
        container01.addProperty("petals.container.name", CONTAINER_01_NAME);
        container01.addComponent(new Component(ENGINE_01_0, ComponentType.SE));
        container01.addComponent(new Component(ENGINE_01_1, ComponentType.SE));
        container01.addServiceAssembly(new ServiceAssembly(SA_01_0));

        domain.addContainers(Arrays.asList(new Container[] { container00, container01 }));

        return domain;
    }

}
